# Open Source OpenADR 3.0 VEN Implementation 

Use pip to install:

```bash
    pip install oadr30_ven_ud
```

Review two test files:
tests/events_test.py - You can use this to pass OpenADR cert testing
test/price_server_test.py - You can use this to populate the VTN with prices from Olivine price servers. 


# oadr3 YAML
[oadr3 yaml](https://github.com/oadr3-org/openadr3-openapi/blob/main/oadr3.0.1.yaml)

